@@ -1,6 +1,6 @@
 /*
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2007 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2008 by Paolo Lucente
 */
 
 /*
@@ -39,6 +39,9 @@ void evaluate_configuration(char *filename, int rows)
     else valid_line = TRUE; 
 
     if (valid_line) {
+      /* debugging the line if required */
+      if (debug) Log(LOG_DEBUG, "DEBUG ( %s ): %s\n", filename, cfg[index]);
+
       /* splitting key, value and name */
       delim = strchr(cfg[index], ':');
       *delim = '\0';
@@ -104,10 +107,7 @@ int parse_configuration_file(char *filename)
 	  break;
         }
 	memset(localbuf, 0, sizeof(localbuf));
-        if (fgets(localbuf, sizeof(localbuf), file) == NULL) {
-	  if (debug) debug_configuration_file(filename, rows); 
-	  break;	
-        }
+        if (fgets(localbuf, sizeof(localbuf), file) == NULL) break;	
         else {
 	  localbuf[sizeof(localbuf)-1] = '\0';
           cfg[rows] = malloc(strlen(localbuf)+2);
@@ -389,16 +389,6 @@ void set_default_values()
   }
 }
 
-void debug_configuration_file(char *filename, int rows)
-{
-  int index = 0;
-
-  while (index < rows) {
-    Log(LOG_DEBUG, "DEBUG ( %s ): %s", filename, cfg[index]);
-    index++;
-  }
-}
-
 int create_plugin(char *filename, char *name, char *type)
 {
   struct plugins_list_entry *plugin, *ptr;
