@@ -1,6 +1,6 @@
 /*  
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2007 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2008 by Paolo Lucente
 */
 
 /*
@@ -123,6 +123,7 @@ int main(int argc,char **argv, char **envp)
   memset(&failed_plugins, 0, sizeof(failed_plugins));
   memset(&req, 0, sizeof(req));
   memset(dummy_tlhdr, 0, sizeof(dummy_tlhdr));
+  memset(sll_mac, 0, sizeof(sll_mac));
   config.acct_type = ACCT_PM;
 
   rows = 0;
@@ -301,7 +302,15 @@ int main(int argc,char **argv, char **envp)
     Log(LOG_INFO, "INFO ( default/core ): Start logging ...\n");
   }
 
-  if (config.logfile) config.logfile_fd = open_logfile(config.logfile);
+  if (config.logfile)
+  {
+    config.logfile_fd = open_logfile(config.logfile);
+    list = plugins_list;
+    while (list) {
+      list->cfg.logfile_fd = config.logfile_fd ;
+      list = list->next;
+    }
+  }
 
   /* Enforcing policies over aggregation methods */
   list = plugins_list;
@@ -476,7 +485,7 @@ int main(int argc,char **argv, char **envp)
   }
   else Log(LOG_INFO, "OK ( default/core ): link type is: %d\n", device.link_type); 
 
-  if (device.link_type != DLT_EN10MB && device.link_type != DLT_IEEE802) {
+  if (device.link_type != DLT_EN10MB && device.link_type != DLT_IEEE802 && device.link_type != DLT_LINUX_SLL) {
     list = plugins_list;
     while (list) {
       if ((list->cfg.what_to_count & COUNT_SRC_MAC) || (list->cfg.what_to_count & COUNT_DST_MAC)) {
