@@ -1,6 +1,6 @@
 /*  
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2007 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2008 by Paolo Lucente
 */
 
 /*
@@ -312,7 +312,16 @@ int main(int argc,char **argv, char **envp)
     Log(LOG_INFO, "INFO ( default/core ): Start logging ...\n");
   }
 
-  if (config.logfile) config.logfile_fd = open_logfile(config.logfile);
+  if (config.logfile)
+  {
+    config.logfile_fd = open_logfile(config.logfile);
+    list = plugins_list;
+    while (list) {
+      list->cfg.logfile_fd = config.logfile_fd ;
+      list = list->next;
+    }
+  }
+
 
   /* Enforcing policies over aggregation methods */
   list = plugins_list;
@@ -1807,7 +1816,11 @@ void readv5FlowSample(SFSample *sample, int expanded, struct packet_ptrs_vector
       case SFLFLOW_EX_PROCESS:      readExtendedProcess(sample); break;
       case SFLFLOW_EX_CLASS:	    readExtendedClass(sample); break;
       case SFLFLOW_EX_TAG:	    readExtendedTag(sample); break;
-      default: skipBytes(sample, length); break; 
+      default:
+	// lengthCheck() here for extra security before skipBytes()
+	if (lengthCheck(sample, start, length) == ERR) return;
+	skipBytes(sample, length);
+	break;
       }
       if (lengthCheck(sample, start, length) == ERR) return;
     }
